@@ -18,10 +18,15 @@ elaborator_perform_ttest <- function(data, treatment, lab_parameter, Visit1 = "R
 
   datasub <- data[data$TRTP == treatment & data[,lab_column] == lab_parameter,]
 
-  differ <- unlist(sapply(unique(datasub$SUBJIDN), function(z){
-    res <- datasub$LBORRES[datasub$SUBJIDN == z & datasub$AVISIT == Visit1] -
-      datasub$LBORRES[datasub$SUBJIDN == z & datasub$AVISIT == Visit2]
+  differ <- unlist(
+    sapply(unique(datasub$SUBJIDN), function(z){
+
+      tmp1 <- datasub$SUBJIDN == z & datasub$AVISIT == Visit1
+      tmp2 <- datasub$SUBJIDN == z & datasub$AVISIT == Visit2
+
+      res <- datasub$LBORRES[tmp1] - datasub$LBORRES[tmp2]
     if (length(res) == 0 || is.na(res)) return(NA) else return(res)
-  }))
+    })
+  )
   testres <- stats::t.test(x = differ)
 }
