@@ -5,6 +5,7 @@
 #' @description
 #' Starts the elaborator application in the client's browser.
 #'
+#' @param elaborator_data data derived for the elaborator app
 #' @param host host link (defaults to the local machine "127.0.0.1")
 #' @param port port number (randomly chosen unless specified as a certain number)
 #' @param browser path to browser exe (defaults to standard browser)
@@ -71,10 +72,25 @@
 #'
 #' @return A shiny app
 
-launch_elaborator <- function(host = "127.0.0.1", port = NULL, browser = NULL){
+launch_elaborator <- function(
+    elaborator_data = NULL,
+    host = "0.0.0.0",
+    port = NULL,
+    browser = NULL
+  ){
+
+  apppars <- list(
+    elaborator_data = elaborator_data
+  )
+  server_env <- environment(elaborator_server)
+  # server_env$apppars <- apppars
+
   elaborator_app <- shiny::shinyApp(ui = elaborator_ui, server = elaborator_server)
   on_ex_browser <- options()$browser
   on.exit(options(browser = on_ex_browser))
   if (!is.null(browser)) options(browser = browser)
+
+
+
   shiny::runApp(elaborator_app, host = host, port = port)
 }
